==> flmngr-8.x-2.0.tar.gz: flmngr/src/Plugin/CKEditorPlugin/flmngr.php <==
<?php

namespace Drupal\flmngr\Plugin\CKEditorPlugin;

use Drupal\flmngr\Plugin\FlmngrEcosystemCKEditorPlugin;

/**
 * Defines the plugin.
 *
 * @CKEditorPlugin(
 *   id = "Flmngr",
 *   label = @Translation("Flmngr"),
 *   module = "flmngr"
 * )
 */
class flmngr extends FlmngrEcosystemCKEditorPlugin
{

    /**
     * {@inheritdoc}
     */
    public function getButtonsDef()
    {
        return array(
            'EmbedImage' => array(
                'label' => 'Embed image without uploading it',
                'image' => 'https://cdn.n1ed.com/cdn/buttons/EmbedImage.png'
            ),
            'FastUploadImage' => array(
                'label' => 'Fast upload image',
                'image' => 'https://cdn.n1ed.com/cdn/buttons/FastUploadImage.png'
            ),
            'FastUploadPreview' => array(
                'label' => 'Fast upload image with preview',
                'image' => 'https://cdn.n1ed.com/cdn/buttons/FastUploadPreview.png'
            ),
            'FastUploadFile' => array(
                'label' => 'Fast upload file',
                'image' => 'https://cdn.n1ed.com/cdn/buttons/FastUploadFile.png'
            ),
            'UploadImage' => array(
                'label' => 'Upload an image',
                'image' => 'https://cdn.n1ed.com/cdn/buttons/UploadImage.png'
            ),
            'UploadPreview' => array(
                'label' => 'Upload image with preview',
                'image' => 'https://cdn.n1ed.com/cdn/buttons/UploadPreview.png'
            ),
            'UploadFile' => array(
                'label' => 'Upload file',
                'image' => 'https://cdn.n1ed.com/cdn/buttons/UploadFile.png'
            ),
            'UploadGallery' => array(
                'label' => 'Upload image gallery',
                'image' => 'https://cdn.n1ed.com/cdn/buttons/UploadGallery.png'
            )
        );
    }

    /**
     * {@inheritdoc}
     */
    public function getPluginName()
    {
        return "Flmngr";
    }

    /**
     * {@inheritdoc}
     */
    public function getModuleName()
    {
        return "flmngr";
    }

    /**
     * {@inheritdoc}
     */
    public function addControlsToForm(&$form, $editor, $config)
    {
        $this->addBooleanToForm($form, $config, "enableFlmngr", true);
        $this->addStringToForm($form, $config, "dirUploads", "");
        $this->addStringToForm($form, $config, "urlFiles", "");
        $this->addStringToForm($form, $config, "urlFileManager", "");
    }
}

==> flmngr-8.x-2.5.tar.gz: flmngr/src/Plugin/CKEditorPlugin/flmngr.php <==
<?php

namespace Drupal\flmngr\Plugin\CKEditorPlugin;

use Drupal\flmngr\Plugin\FlmngrEcosystemCKEditorPlugin;
use Drupal\editor\Entity\Editor;

/**
 * Defines the plugin.
 *
 * @CKEditorPlugin(
 *   id = "Flmngr",
 *   label = @Translation("Flmngr"),
 *   module = "flmngr"
 * )
 */
class flmngr extends FlmngrEcosystemCKEditorPlugin
{

    /**
     * {@inheritdoc}
     */
    public function getButtonsDef()
    {
        return array(
            'EmbedImage' => array(
                'label' => 'Embed image without uploading it',
                'image' => 'https://n1ed.com/cdn/buttons/EmbedImage.png'
            ),
            'FastUploadImage' => array(
                'label' => 'Fast upload image',
                'image' => 'https://n1ed.com/cdn/buttons/FastUploadImage.png'
            ),
            'FastUploadPreview' => array(
                'label' => 'Fast upload image with preview',
                'image' => 'https://n1ed.com/cdn/buttons/FastUploadPreview.png'
            ),
            'FastUploadFile' => array(
                'label' => 'Fast upload file',
                'image' => 'https://n1ed.com/cdn/buttons/FastUploadFile.png'
            ),
            'UploadImage' => array(
                'label' => 'Upload an image',
                'image' => 'https://n1ed.com/cdn/buttons/UploadImage.png'
            ),
            'UploadPreview' => array(
                'label' => 'Upload image with preview',
                'image' => 'https://n1ed.com/cdn/buttons/UploadPreview.png'
            ),
            'UploadFile' => array(
                'label' => 'Upload file',
                'image' => 'https://n1ed.com/cdn/buttons/UploadFile.png'
            ),
            'UploadGallery' => array(
                'label' => 'Upload image gallery',
                'image' => 'https://n1ed.com/cdn/buttons/UploadGallery.png'
            )
        );
    }

    /**
     * {@inheritdoc}
     */
    public function getPluginName()
    {
        return "Flmngr";
    }

    /**
     * {@inheritdoc}
     */
    public function getModuleName()
    {
        return "flmngr";
    }

    /**
     * {@inheritdoc}
     */
    public function getDependencies(Editor $editor)
    {
        return array(
            //"FileUploader"
        );
    }

    /**
     * {@inheritdoc}
     */
    public function addControlsToForm(&$form, $editor, $config)
    {
        $this->addBooleanToForm($form, $config, "enableFlmngr", true);

        $this->addStringToForm($form, $config, "dirUploads", "");
        $this->addStringToForm($form, $config, "urlFiles", "");
        $this->addStringToForm($form, $config, "urlFileManager", "");
    }
}
